@@ -351,7 +351,7 @@ Object.extend(Object.extend(Tree, Widget), {
 	setTimeout(this.__initNavRebuild.bind(this, this.body.rows.length), 100);
 
         registerFocus(this);
-	keyLogEvent(this.__keyEventsCB.bindAsEventListener(this));
+	keyLogEvent(this, this.__keyEventsCB.bindAsEventListener(this));
     },
     _bodySort: function(dir, col_num) {
 	this.__sorted_rows = [];
@@ -390,6 +390,7 @@ Object.extend(Object.extend(Tree, Widget), {
 	    for (var i = 0; i < this.body.rows.length; i++)
 		this.body.rows[i]._rebuildNav();
 	    this._setAlternate(this.body);
+            this.__initNavRebuild(this.body.rows.length);
 	}
     },
     // On the same level
@@ -470,8 +471,6 @@ Object.extend(Object.extend(Tree, Widget), {
     __keyEventsCB: function(event) {
 	var keyCode = Event.getKeyCode(event);
 	var row;
-	if (focused_widget != this.id)
-	    return;
 
 	if (keyCode == 38)  { 		// Up-arrow
 	    if (row = this.getPrevRow())
